@@ -1,19 +1,25 @@
-from flask import abort, jsonify
+from flask import abort, jsonify,request
 from flask_restful import Resource
 from flask_simplelogin import login_required
 import datetime
-from hiddifypanel.models import StrConfig,BoolConfig,User,Domain,get_hconfigs
-
+from hiddifypanel.models import StrConfig,BoolConfig,User,Domain,get_hconfigs,Proxy
+from urllib.parse import urlparse
 
 class AllResource(Resource):
     def get(self):
         products = User.query.all() or abort(204)
-        return jsonify(
-            {"users": [u.to_dict() for u in User.query.filter((User.monthly_usage_limit_GB>User.current_usage_GB)).filter(User.expiry_time>=datetime.date.today()).all()],
+        response= jsonify(
+            {"users": [u.to_dict() for u in User.query.filter((User.usage_limit_GB>User.current_usage_GB)).filter(User.expiry_time>=datetime.date.today()).all()],
             "domains": [u.to_dict() for u in Domain.query.all()],
+            "proxies": [u.to_dict() for u in Proxy.query.all()],
             "hconfigs": get_hconfigs()
             }
         )
+        o = urlparse(request.base_url)
+        domain=o.hostname
+        response.headers.add('Content-disposition', f'attachment; filename=hiddify-{domain}-{datetime.datetime.now()}.json');
+
+        return response
 
 
 class UserResource(Resource):
